@@ -1,6 +1,6 @@
-/* $Id: filesystem.cpp,v 1.74 2005/06/24 22:41:49 Sirp Exp $ */
+/* $Id: filesystem.cpp 8269 2005-09-17 15:06:28Z ott $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -49,7 +49,8 @@ BPath be_path;
 
 //for getenv
 #include <cstdlib>
-
+#include <cerrno>
+#include <cstring>
 #include <algorithm>
 #include <fstream>
 #include <iostream>
@@ -316,6 +317,41 @@ void make_directory(const std::string& path)
 #endif
 }
 
+//this deletes a directory with no hidden files and subdirectories
+//also deletes a single file
+bool delete_directory(const std::string& path)
+{
+	bool ret = true;
+	std::vector<std::string> files;
+	std::vector<std::string> dirs;
+
+	get_files_in_dir(path, &files, &dirs, ENTIRE_FILE_PATH);
+
+	if(!files.empty()) {
+		for(std::vector<std::string>::const_iterator i = files.begin(); i != files.end(); ++i) {
+			errno = 0;
+			if(remove((*i).c_str()) != 0) {
+				LOG_FS << "remove(" << (*i) << "): " << strerror(errno) << "\n";
+				ret = false;
+			}
+		}
+	}
+
+	if(!dirs.empty()) {
+		for(std::vector<std::string>::const_iterator j = dirs.begin(); j != dirs.end(); ++j) {
+			if(!delete_directory(*j))
+				ret = false;
+		}
+	}
+
+	errno = 0;
+	if(remove(path.c_str()) != 0) {
+		LOG_FS << "remove(" << path << "): " << strerror(errno) << "\n";
+		ret = false;
+	}
+	return ret;
+}
+
 std::string get_cwd()
 {
 	char buf[1024];
@@ -434,13 +470,17 @@ std::istream *istream_file(std::string const &fname)
 		std::ifstream *s = new std::ifstream((game_config::path + "/" + fname).c_str(),std::ios_base::binary);
 		if (s->is_open())
 			return s;
+		LOG_FS << "could not open " << fname << " for reading.\n";
 		delete s;
 	}
 #endif
 
 	// FIXME: why do we rely on this even with relative paths ?
 	// still useful with zipios, for things like cache and prefs
-	return new std::ifstream(fname.c_str(),std::ios_base::binary);
+	std::istream *s = new std::ifstream(fname.c_str(), std::ios_base::binary);
+	if (s->fail())
+		LOG_FS << "streaming " << fname << " failed.\n";
+	return s;
 }
 
 std::string read_file(std::string const &fname)
@@ -730,6 +770,11 @@ void binary_paths_manager::cleanup()
 	}
 }
 
+void clear_binary_paths_cache()
+{
+	binary_paths_cache.clear();
+}
+
 const std::vector<std::string>& get_binary_paths(const std::string& type)
 {
 	const paths_map::const_iterator itor = binary_paths_cache.find(type);
