@@ -1,6 +1,6 @@
-/* $Id: filesystem.hpp,v 1.37 2005/06/04 19:16:05 ott Exp $ */
+/* $Id: filesystem.hpp 8269 2005-09-17 15:06:28Z ott $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -56,6 +56,7 @@ std::string get_user_data_dir();
 std::string get_cwd();
 
 void make_directory(const std::string& dirname);
+bool delete_directory(const std::string& dirname);
 
 //basic disk I/O
 bool filesystem_init();
@@ -132,6 +133,7 @@ private:
 	std::vector<std::string> paths_;
 };
 
+void clear_binary_paths_cache();
 
 //function which, given a type of binary, e.g. 'images', 'sounds', etc,
 //will return a vector with all possible paths to that type of binary
