@@ -1,4 +1,4 @@
-/* $Id: game.cpp 8285 2005-09-18 19:08:31Z ott $ */
+/* $Id: game.cpp 8821 2005-11-12 19:23:56Z brunowolff $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -553,7 +553,7 @@ bool game_controller::play_multiplayer_mode()
 		}
 
 		char buf[20];
-		sprintf(buf,"%d",side_num);
+		snprintf(buf,sizeof(buf),"%d",side_num);
 		(*itors.first)->values["side"] = buf;
 
 		(*itors.first)->values["canrecruit"] = "1";
@@ -996,6 +996,11 @@ void game_controller::download_campaigns()
 			return;
 		}
 
+		if(!check_names_legal(cfg)) {
+			gui::show_error_message(disp(), "The campaign has an invalid file or directory name and can not be installed.");
+			return;
+		}
+
 		//remove any existing versions of the just downloaded campaign
 		//assuming it consists of a dir and a cfg file
 		remove_campaign(campaigns[index]);
@@ -1406,7 +1411,8 @@ void game_controller::refresh_game_cfg(bool reset_translations)
 
 			const config* const units = game_config_.child("units");
 			if(units != NULL) {
-				units_data_.set_config(*units);
+				const bool allow_advancefrom = defines_map_.find("MULTIPLAYER") == defines_map_.end();
+				units_data_.set_config(*units,allow_advancefrom);
 			}
 
 			old_defines_map_ = defines_map_;
