@@ -1,6 +1,6 @@
-/* $Id: hotkeys.cpp,v 1.78 2005/06/04 19:16:05 ott Exp $ */
+/* $Id: hotkeys.cpp 8303 2005-09-18 23:39:42Z ott $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -84,7 +84,7 @@ const struct {
 	{ hotkey::HOTKEY_EDIT_LOAD_MAP, "editloadmap", N_("Load Map"),true },
 	{ hotkey::HOTKEY_EDIT_SAVE_MAP, "editsavemap", N_("Save Map"),true },
 	{ hotkey::HOTKEY_EDIT_SAVE_AS, "editsaveas", N_("Save As"),true },
-	{ hotkey::HOTKEY_EDIT_SET_START_POS, "editsetstartpos", N_("Set Player Start Position"),true },
+	{ hotkey::HOTKEY_EDIT_SET_START_POS, "editsetstartpos", N_("Set Player's keep"),true },
 	{ hotkey::HOTKEY_EDIT_FLOOD_FILL, "editfloodfill", N_("Flood Fill"),true },
 	{ hotkey::HOTKEY_EDIT_FILL_SELECTION, "editfillselection", N_("Fill Selection"),true },
 	{ hotkey::HOTKEY_EDIT_CUT, "editcut", N_("Cut"),true },
@@ -107,6 +107,8 @@ const struct {
 	{ hotkey::HOTKEY_CHAT_LOG, "chatlog", N_("View Chat Log"), false },
 	{ hotkey::HOTKEY_USER_CMD, "command", N_("Enter user command"), false },
 
+	{ hotkey::HOTKEY_LANGUAGE, "changelanguage", N_("Change the language"), true },
+
 	{ hotkey::HOTKEY_NULL, NULL, NULL, true }
 };
 
@@ -157,7 +159,7 @@ std::string hotkey_item::get_name() const
 		if (shift_)
 			str << "shift+";
 		if (cmd_)
-			str << "command+";
+			str << "cmd+";
 
 		str << SDL_GetKeyName(SDLKey(keycode_));
 		return str.str();
@@ -644,6 +646,10 @@ void execute_command(display& disp, HOTKEY_COMMAND command, command_executor* ex
 			if(executor)
 				executor->edit_refresh();
 			break;
+		 case HOTKEY_LANGUAGE:
+			if(executor)
+				executor->change_language();
+			break;
 		default:
 			std::cerr << "command_executor: unknown command number " << command << ", ignoring.\n";
 			break;
