@@ -1,4 +1,4 @@
-/* $Id: map.cpp 7396 2005-07-02 21:37:20Z ott $ */
+/* $Id: map.cpp 8821 2005-11-12 19:23:56Z brunowolff $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -126,9 +126,9 @@ gamemap::location::location(const config& cfg) : x(-1), y(-1)
 void gamemap::location::write(config& cfg) const
 {
 	char buf[50];
-	sprintf(buf,"%d",x+1);
+	snprintf(buf,sizeof(buf),"%d",x+1);
 	cfg["x"] = buf;
-	sprintf(buf,"%d",y+1);
+	snprintf(buf,sizeof(buf),"%d",y+1);
 	cfg["y"] = buf;
 }
 
