@@ -1,4 +1,4 @@
-/* $Id: network_worker.hpp 7716 2005-08-05 21:53:03Z j_daniel $ */
+/* $Id: network_worker.hpp 8583 2005-10-16 00:16:59Z dave $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -46,7 +46,7 @@ TCPsocket get_received_data(TCPsocket sock, std::vector<char>& buf);
 
 void queue_data(TCPsocket sock, std::vector<char>& buf);
 bool socket_locked(TCPsocket sock);
-void close_socket(TCPsocket sock);
+bool close_socket(TCPsocket sock);
 TCPsocket detect_error();
 
 std::pair<network::statistics,network::statistics> get_current_transfer_stats(TCPsocket sock);
