@@ -1,4 +1,4 @@
-/* $Id: playlevel.cpp 8300 2005-09-18 22:38:06Z ott $ */
+/* $Id: playlevel.cpp 8865 2005-11-17 04:18:36Z brunowolff $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -220,6 +220,10 @@ LEVEL_RESULT play_level(const game_data& gameinfo, const config& game_config,
 			save_id=(**ui)["description"];
 		}
 
+		if(save_id.empty()) {
+			save_id="Unknown";
+		}
+
 		//make sure the 'save_id' is unique
 		while(seen_save_ids.count(save_id)) {
 			save_id += "_";
@@ -295,28 +299,30 @@ LEVEL_RESULT play_level(const game_data& gameinfo, const config& game_config,
 
 			//see if the side specifies its location. Otherwise start it at the map-given
 			//starting position
-			const std::string& has_loc = (**ui)["x"];
 			gamemap::location start_pos(**ui);
 
-			if(has_loc.empty()) {
-				start_pos = map.starting_position(side);
-				LOG_NG << "initializing side '" << (**ui)["side"] << "' at "
-				       << start_pos << '\n';
-			}
-
 			if(map.empty()) {
 				throw game::load_game_failed("Map not found");
 			}
 
-			if(!start_pos.valid() && new_unit.side() == 1) {
-				throw game::load_game_failed("No starting position for side 1");
+			if((**ui)["x"].empty() && (**ui)["y"].empty()) {
+				start_pos = map.starting_position(side);
 			}
 
-			if(start_pos.valid()) {
-				new_unit.new_turn();
-				units.insert(std::pair<gamemap::location,unit>(
-							map.starting_position(new_unit.side()), new_unit));
+			if(!start_pos.valid() || !map.on_board(start_pos)) {
+				throw game::load_game_failed(
+					"Invalid starting position (" +
+					lexical_cast<std::string>(start_pos.x+1) +
+					"," + lexical_cast<std::string>(start_pos.y+1) +
+					") for the leader of side " +
+					lexical_cast<std::string>(side) + ".");
 			}
+
+			new_unit.new_turn();
+			units.insert(std::pair<gamemap::location,unit>(
+						map.starting_position(new_unit.side()), new_unit));
+			LOG_NG << "initializing side '" << (**ui)["side"] << "' at "
+			       << start_pos << '\n';
 		}
 
 		//if the game state specifies units that can be recruited for the player
@@ -341,10 +347,23 @@ LEVEL_RESULT play_level(const game_data& gameinfo, const config& game_config,
 			const std::string& y = (**su)["y"];
 
 			const gamemap::location loc(**su);
-			if(x.empty() || y.empty() || !map.on_board(loc)) {
+			if(x.empty() && y.empty()) {
 				if(player) {
 					player->available_units.push_back(new_unit);
+					LOG_NG << "inserting unit on recall list for side " << new_unit.side() << "\n";
+				} else {
+					throw game::load_game_failed(
+						"Attempt to create a unit on the recall list for side " +
+						lexical_cast<std::string>(side) +
+						", which does not have a recall list.");
 				}
+			} else if(!loc.valid() || !map.on_board(loc)) {
+				throw game::load_game_failed(
+					"Invalid starting position (" +
+					lexical_cast<std::string>(loc.x+1) +
+					"," + lexical_cast<std::string>(loc.y+1) +
+					") for a unit on side " +
+					lexical_cast<std::string>(side) + ".");
 			} else {
 				units.insert(std::pair<gamemap::location,unit>(loc,new_unit));
 				LOG_NG << "inserting unit for side " << new_unit.side() << "\n";
