@@ -1,4 +1,4 @@
-/* $Id: replay.cpp 7396 2005-07-02 21:37:20Z ott $ */
+/* $Id: replay.cpp 8865 2005-11-17 04:18:36Z brunowolff $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -234,7 +234,7 @@ void replay::add_recruit(int value, const gamemap::location& loc)
 	config val;
 
 	char buf[100];
-	sprintf(buf,"%d",value);
+	snprintf(buf,sizeof(buf),"%d",value);
 	val["value"] = buf;
 
 	loc.write(val);
@@ -249,7 +249,7 @@ void replay::add_recall(int value, const gamemap::location& loc)
 	config val;
 
 	char buf[100];
-	sprintf(buf,"%d",value);
+	snprintf(buf,sizeof(buf),"%d",value);
 	val["value"] = buf;
 
 	loc.write(val);
@@ -264,7 +264,7 @@ void replay::add_disband(int value)
 	config val;
 
 	char buf[100];
-	sprintf(buf,"%d",value);
+	snprintf(buf,sizeof(buf),"%d",value);
 	val["value"] = buf;
 
 	cmd->add_child("disband",val);
@@ -279,7 +279,7 @@ void replay::add_attack(const gamemap::location& a, const gamemap::location& b,
 {
 	add_pos("attack",a,b);
 	char buf[100];
-	sprintf(buf,"%d",weapon);
+	snprintf(buf,sizeof(buf),"%d",weapon);
 	current_->child("attack")->values["weapon"] = buf;
 }
 
@@ -304,7 +304,7 @@ void replay::add_value(const std::string& type, int value)
 	config val;
 
 	char buf[100];
-	sprintf(buf,"%d",value);
+	snprintf(buf,sizeof(buf),"%d",value);
 	val["value"] = buf;
 
 	cmd->add_child(type,val);
