@@ -1,4 +1,4 @@
-/* $Id: reports.cpp 7960 2005-08-21 20:58:48Z gruikya $ */
+/* $Id: reports.cpp 8821 2005-11-12 19:23:56Z brunowolff $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -375,7 +375,7 @@ Units cannot be killed by poison alone. The poison will not reduce it below 1 HP
 
 	case SIDE_PLAYING: {
 		char buf[50];
-		sprintf(buf,"terrain/flag-team%d-1.png",team::get_side_colour_index(playing_side));
+		snprintf(buf,sizeof(buf),"terrain/flag-team%d-1.png",team::get_side_colour_index(playing_side));
 
 		u = find_leader(units,playing_side);
 		return report("",buf,u != units.end() ? u->second.description() : "");
