@@ -1,4 +1,4 @@
-/* $Id: binary_or_text.cpp 7396 2005-07-02 21:37:20Z ott $ */
+/* $Id: binary_or_text.cpp 8861 2005-11-15 22:52:07Z jhinrichs $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Copyright (C) 2005 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
@@ -12,7 +12,7 @@
    See the COPYING file for more details.
 */
 
-#include "global.hpp"
+#include "../global.hpp"
 
 #include "config.hpp"
 #include "filesystem.hpp"
