@@ -1,6 +1,6 @@
-/* $Id: string_utils.cpp,v 1.22 2005/06/04 19:16:06 ott Exp $ */
+/* $Id: string_utils.cpp 8214 2005-09-12 21:33:34Z gruikya $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Copyright (C) 2005 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
    Copyright (C) 2005 by Philippe Plantier <ayin@anathas.org>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -233,14 +233,12 @@ std::string interpolate_variables_into_string(const std::string &str, variable_s
 	return res;
 }
 
-//prepend all special characters with a backslash
-//special characters are:
-//#@{}+-,\*
-std::string &escape(std::string &str)
+//Prepends a configurable set of characters with a backslash
+std::string &escape(std::string &str, const std::string& special_chars)
 {
 	std::string::size_type pos = 0;
 	do {
-		pos = str.find_first_of("#@{}+-,\\*", pos);
+		pos = str.find_first_of(special_chars, pos);
 		if (pos == std::string::npos)
 			break;
 		str.insert(pos, 1, '\\');
@@ -249,6 +247,15 @@ std::string &escape(std::string &str)
 	return str;
 }
 
+//prepend all special characters with a backslash
+//special characters are:
+//#@{}+-,\*=
+std::string& escape(std::string& str)
+{
+	static const std::string special_chars("#@{}+-,\\*=");
+	return escape(str, special_chars);
+}
+
 // remove all escape characters (backslash)
 std::string &unescape(std::string &str)
 {
@@ -603,7 +610,7 @@ utf8_string lowercase(const utf8_string& s)
 		std::string res;
 
 		for(;itor != utf8_iterator::end(s); ++itor) {
-#ifdef __APPLE__
+#if defined(__APPLE__) || defined(__OpenBSD__)
 			// FIXME: Should we support towupper on recent OSX platforms?
 			wchar_t uchar = *itor;
 			if(uchar >= 0 && uchar < 0x100)
