@@ -1,7 +1,21 @@
+/* $Id: server.cpp 8383 2005-09-25 17:54:37Z isaac $ */
+/*
+   Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
+   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY.
+
+   See the COPYING file for more details.
+*/
+
 #include "../global.hpp"
 
 #include "../config.hpp"
 #include "../game_config.hpp"
+#include "../log.hpp"
 #include "../network.hpp"
 #include "../util.hpp"
 #include "../wassert.hpp"
@@ -10,9 +24,12 @@
 #include "SDL.h"
 
 #include "game.hpp"
+#include "filesystem.hpp"
 #include "input_stream.hpp"
 #include "metrics.hpp"
+#include "serialization/parser.hpp"
 #include "player.hpp"
+#include "proxy.hpp"
 
 #include <algorithm>
 #include <cstdlib>
@@ -69,7 +86,7 @@ void truncate_message(t_string& str)
 class server
 {
 public:
-	server(int port, input_stream& input);
+	server(int port, input_stream& input, const config& cfg, size_t nthreads);
 	void run();
 private:
 	void process_data(network::connection sock, config& data, config& gamelist);
@@ -79,7 +96,7 @@ private:
 	void process_data_from_player_in_lobby(network::connection sock, config& data, config& gamelist);
 	void process_data_from_player_in_game(network::connection sock, config& data, config& gamelist);
 
-	void process_command(const std::string& cmd);
+	std::string process_command(const std::string& cmd);
 
 	void delete_game(std::vector<game>::iterator i);
 
@@ -88,6 +105,7 @@ private:
 	const network::manager net_manager_;
 	const network::server_manager server_;
 
+	config version_query_response_;
 	config login_response_;
 	config join_lobby_response_;
 
@@ -108,15 +126,52 @@ private:
 
 	metrics metrics_;
 
+	const config& cfg_;
+
+	std::set<std::string> accepted_versions_;
+	std::map<std::string,config> redirected_versions_;
+	std::map<std::string,config> proxy_versions_;
+
 	bool is_ip_banned(const std::string& ip);
 	std::string ban_ip(const std::string& mask);
 	std::vector<std::string> bans_;
+
+	std::string admin_passwd_;
+	std::set<network::connection> admins_;
 };
 
-server::server(int port, input_stream& input) : net_manager_(5), server_(port), not_logged_in_(players_), lobby_players_(players_), last_stats_(time(NULL)), input_(input)
+server::server(int port, input_stream& input, const config& cfg, size_t nthreads) : net_manager_(nthreads), server_(port),
+    not_logged_in_(players_), lobby_players_(players_), last_stats_(time(NULL)), input_(input), cfg_(cfg), admin_passwd_(cfg["passwd"])
 {
+	version_query_response_.add_child("version");
+
 	login_response_.add_child("mustlogin");
-	login_response_["version"] = game_config::version;
+
+	const std::string& versions = cfg_["versions_accepted"];
+	if(versions.empty() == false) {
+		const std::vector<std::string> accepted(utils::split(versions));
+		for(std::vector<std::string>::const_iterator i = accepted.begin(); i != accepted.end(); ++i) {
+			accepted_versions_.insert(*i);
+		}
+	} else {
+		accepted_versions_.insert(game_config::version);
+	}
+
+	const config::child_list& redirects = cfg_.get_children("redirect");
+	for(config::child_list::const_iterator i = redirects.begin(); i != redirects.end(); ++i) {
+		const std::vector<std::string> versions(utils::split((**i)["version"]));
+		for(std::vector<std::string>::const_iterator j = versions.begin(); j != versions.end(); ++j) {
+			redirected_versions_[*j] = **i;
+		}
+	}
+
+	const config::child_list& proxies = cfg_.get_children("proxy");
+	for(config::child_list::const_iterator p = proxies.begin(); p != proxies.end(); ++p) {
+		const std::vector<std::string> versions(utils::split((**p)["version"]));
+		for(std::vector<std::string>::const_iterator j = versions.begin(); j != versions.end(); ++j) {
+			proxy_versions_[*j] = **p;
+		}
+	}
 
 	join_lobby_response_.add_child("join_lobby");
 }
@@ -170,14 +225,14 @@ void server::dump_stats()
 		"\tend_interval = " << last_stats_ << std::endl;
 }
 
-void server::process_command(const std::string& cmd)
+std::string server::process_command(const std::string& cmd)
 {
+	std::ostringstream out;
 	const std::string::const_iterator i = std::find(cmd.begin(),cmd.end(),' ');
 	const std::string command(cmd.begin(),i);
 	if(command == "msg") {
 		if(i == cmd.end()) {
-			std::cout << "you must type a message" << std::endl;
-			return;
+			return "you must type a message";
 		}
 
 		const std::string msg(i+1,cmd.end()); lobby_players_.send_data(construct_server_message(msg,lobby_players_));
@@ -185,72 +240,71 @@ void server::process_command(const std::string& cmd)
 			g->send_data(construct_server_message(msg,*g));
 		}
 
-		std::cout << "message '" << msg << "' relayed to players\n";
+		out << "message '" << msg << "' relayed to players\n";
 	} else if(command == "status") {
-		std::cout << "STATUS REPORT\n---\n";
+		out << "STATUS REPORT\n---\n";
 		for(player_map::const_iterator i = players_.begin(); i != players_.end(); ++i) {
 			const network::connection_stats& stats = network::get_connection_stats(i->first);
 			const int time_connected = stats.time_connected/1000;
 			const int seconds = time_connected%60;
 			const int minutes = (time_connected/60)%60;
 			const int hours = time_connected/(60*60);
-			std::cout << "'" << i->second.name() << "' @ " << network::ip_address(i->first) << " connected for " << hours << ":" << minutes << ":" << seconds << " sent " << stats.bytes_sent << " bytes, received " << stats.bytes_received << " bytes\n";
+			out << "'" << i->second.name() << "' @ " << network::ip_address(i->first) << " connected for " << hours << ":" << minutes << ":" << seconds << " sent " << stats.bytes_sent << " bytes, received " << stats.bytes_received << " bytes\n";
 		}
 
-		std::cout << "---" << std::endl;
+		out << "---";
 	} else if(command == "metrics") {
-		std::cout << metrics_ << std::endl;
+		out << metrics_;
 	} else if(command == "ban") {
 
 		if(i == cmd.end()) {
-			std::cout << "BAN LIST\n---\n";
+			out << "BAN LIST\n---\n";
 			for(std::vector<std::string>::const_iterator i = bans_.begin(); i != bans_.end(); ++i) {
-				std::cout << *i << "\n";
+				out << *i << "\n";
 			}
-			std::cout << "---" << std::endl;
+			out << "---";
 		} else {
 			const std::string mask(i+1,cmd.end());
 			const std::string& diagnostic = ban_ip(mask);
 			if(diagnostic != "") {
-				std::cout << "Could not ban '" << mask << "': " << diagnostic << std::endl;
+				out << "Could not ban '" << mask << "': " << diagnostic;
 			} else {
-				std::cout << "Set ban on '" << mask << "'\n";
+				out << "Set ban on '" << mask << "'\n";
 			}
 		}
 	} else if(command == "unban") {
 		if(i == cmd.end()) {
-			std::cout << "You must enter a mask to unban" << std::endl;
-			return;
+			return "You must enter a mask to unban";
 		}
 
 		const std::string mask(i+1,cmd.end());
 
 		const std::vector<std::string>::iterator itor = std::remove(bans_.begin(),bans_.end(),mask);
 		if(itor == bans_.end()) {
-			std::cout << "there is no ban on '" << mask << "'" << std::endl;
+			out << "there is no ban on '" << mask << "'";
 		} else {
 			bans_.erase(itor,bans_.end());
-			std::cout << "ban removed on '" << mask << "'" << std::endl;
+			out << "ban removed on '" << mask << "'";
 		}
 
 	} else if(command == "kick") {
 		if(i == cmd.end()) {
-			std::cout << "you must enter a nick to kick\n";
-			return;
+			return "you must enter a nick to kick";
 		}
 
 		const std::string nick(i+1,cmd.end());
 
 		for(player_map::const_iterator j = players_.begin(); j != players_.end(); ++j) {
 			if(j->second.name() == nick) {
-				std::cout << "kicking nick '" << j->second.name() << "'\n";
 				throw network::error("",j->first);
 			}
 		}
 	} else {
-		std::cout << "command '" << command << "' is not recognized" << std::endl;
-		std::cout << "available commands are: msg <message>, status, metrics, ban [<nick>], unban <nick>, kick <nick>" << std::endl;
+		out << "command '" << command << "' is not recognized";
+		out << "available commands are: msg <message>, status, metrics, ban [<nick>], unban <nick>, kick <nick>";
 	}
+
+	return out.str();
 }
 
 void server::run()
@@ -271,7 +325,7 @@ void server::run()
 			//process admin commands
 			std::string admin_cmd;
 			if(input_.read_line(admin_cmd)) {
-				process_command(admin_cmd);
+				std::cout << process_command(admin_cmd) << std::endl;
 			}
 
 			//make sure we log stats every 5 minutes
@@ -287,7 +341,7 @@ void server::run()
 				network::send_data(construct_error("You are banned."),sock);
 				network::disconnect(sock);
 			} else if(sock) {
-				network::send_data(login_response_,sock);
+				network::send_data(version_query_response_,sock);
 				not_logged_in_.add_player(sock);
 			}
 
@@ -329,6 +383,9 @@ void server::run()
 				}
 
 				if(e.socket) {
+					if(proxy::is_proxy(e.socket)) {
+						proxy::disconnect(e.socket);
+					}
 					e.disconnect();
 				}
 
@@ -349,9 +406,12 @@ void server::run()
 
 void server::process_data(const network::connection sock, config& data, config& gamelist)
 {
+	if(proxy::is_proxy(sock)) {
+		proxy::received_data(sock,data);
+	}
 	//if someone who is not yet logged in is sending
 	//login details
-	if(not_logged_in_.is_member(sock)) {
+	else if(not_logged_in_.is_member(sock)) {
 		process_login(sock,data,gamelist);
 	} else if(const config* query = data.child("query")) {
 		process_query(sock,*query,gamelist);
@@ -364,6 +424,51 @@ void server::process_data(const network::connection sock, config& data, config&
 
 void server::process_login(const network::connection sock, const config& data, config& gamelist)
 {
+	//see if client is sending their version number
+	const config* const version = data.child("version");
+	if(version != NULL) {
+		const std::string& version_str = (*version)["version"];
+
+		if(accepted_versions_.count(version_str)) {
+			std::cerr << "player joined using accepted version " << version_str << ": telling them to log in\n";
+			network::send_data(login_response_,sock);
+		} else {
+			const std::map<std::string,config>::const_iterator i = redirected_versions_.find(version_str);
+			if(i != redirected_versions_.end()) {
+				std::cerr << "player joined using version " << version_str << ": redirecting them to "
+				          << i->second["host"] << ":" << i->second["port"] << "\n";
+				config response;
+				response.add_child("redirect",i->second);
+				network::send_data(response,sock);
+			} else {
+				const std::map<std::string,config>::const_iterator i = proxy_versions_.find(version_str);
+
+				if(i != proxy_versions_.end()) {
+					std::cerr << "player joined using version " << version_str << ": connecting them by proxy to "
+					          << i->second["host"] << ":" << i->second["port"] << "\n";
+
+					proxy::create_proxy(sock,i->second["host"],lexical_cast_default<int>(i->second["port"],15000));
+				} else {
+
+					std::cerr << "player joined using unknown version " << version_str << ": rejecting them\n";
+					config response;
+					if(accepted_versions_.empty() == false) {
+						response["version"] = *accepted_versions_.begin();
+					} else if(redirected_versions_.empty() == false) {
+						response["version"] = redirected_versions_.begin()->first;
+					} else {
+						std::cerr << "this server doesn't accept any versions at all\n";
+						response["version"] = "null";
+					}
+
+					network::send_data(response,sock);
+				}
+			}
+		}
+
+		return;
+	}
+
 	const config* const login = data.child("login");
 
 	//client must send a login first.
@@ -443,6 +548,11 @@ void server::process_query(const network::connection sock, const config& query,
 	if(query["type"] == "metrics") {
 		//a query for server data from a player
 		response << metrics_;
+	} else if(admin_passwd_.empty() == false && query["type"] == admin_passwd_) {
+		admins_.insert(sock);
+		response << "You are now recognized as an administrator";
+	} else if(admins_.count(sock) != 0) {
+		response << process_command(query["type"]);
 	} else {
 		response << "Error: unrecognized query";
 	}
@@ -658,6 +768,11 @@ void server::process_data_from_player_in_game(const network::connection sock, co
 				g->level().values["map_data"] = data["map_data"];
 				g->level().values["map"] = data["map"];
 			}
+			g->level().values["mp_use_map_settings"] = data["mp_use_map_settings"];
+			g->level().values["mp_village_gold"] = data["mp_village_gold"];
+			g->level().values["mp_fog"] = data["mp_fog"];
+			g->level().values["mp_shroud"] = data["mp_shroud"];
+			g->level().values["experience_modifier"] = data["experience_modifier"];
 
 			//update our config object which describes the
 			//open games, and notifies the game of where its description
@@ -886,9 +1001,12 @@ void server::delete_game(std::vector<game>::iterator i)
 int main(int argc, char** argv)
 {
 	int port = 15000;
+	size_t nthreads = 5;
 
 	network::set_default_send_size(4096);
 
+	config configuration;
+
 #ifndef FIFODIR
 # define FIFODIR "/var/run/wesnothd"
 #endif
@@ -900,10 +1018,24 @@ int main(int argc, char** argv)
 			continue;
 		}
 
-		if((val == "--max_packet_size" || val == "-m") && arg+1 != argc) {
+		if((val == "--config" || val == "-c") && arg+1 != argc) {
+			scoped_istream stream = istream_file(argv[++arg]);
+
+			std::string errors;
+			try {
+				read(configuration,*stream,&errors);
+				if(errors.empty() == false) {
+					std::cerr << "WARNING: errors reading configuration file: " << errors << "\n";
+				}
+			} catch(config::error& e) {
+				std::cerr << "ERROR: could not read configuration file: '" << e.message << "'\n";
+				return -1;
+			}
+		} else if((val == "--max_packet_size" || val == "-m") && arg+1 != argc) {
 			network::set_default_send_size(size_t(atoi(argv[++arg])));
-		}
-		else if((val == "--port" || val == "-p") && arg+1 != argc) {
+		} else if(val == "--verbose" || val == "-v") {
+			lg::set_log_domain_severity("all",2);
+		} else if((val == "--port" || val == "-p") && arg+1 != argc) {
 			port = atoi(argv[++arg]);
 		} else if(val == "--help" || val == "-h") {
 			std::cout << "usage: " << argv[0]
@@ -911,9 +1043,10 @@ int main(int argc, char** argv)
 				<< "  -d  --daemon               Runs wesnothd as a daemon\n"
 				<< "  -m, --max_packet_size n    Sets the maximal packet size to n\n"
 				<< "  -p, --port                 Binds the server to the specified port\n"
-				<< "  -v, --version              Returns the server version\n";
+				<< "  -V, --version              Returns the server version\n"
+				<< "  -t, --threads n            Uses n worker threads for network I/O (default: 5)\n";
 			return 0;
-		} else if(val == "--version" || val == "-v") {
+		} else if(val == "--version" || val == "-V") {
 			std::cout << "Battle for Wesnoth server " << game_config::version
 				<< "\n";
 			return 0;
@@ -933,6 +1066,11 @@ int main(int argc, char** argv)
 
 			setsid();
 #endif
+		} else if((val == "--threads" || val == "-t") && arg+1 != argc) {
+			nthreads = atoi(argv[++arg]);
+			if(nthreads > 30) {
+				nthreads = 30;
+			}
 		} else if(val[0] == '-') {
 			std::cerr << "unknown option: " << val << "\n";
 			return 0;
@@ -944,7 +1082,7 @@ int main(int argc, char** argv)
 	input_stream input(fifo_path);
 
 	try {
-		server(port,input).run();
+		server(port,input,configuration,nthreads).run();
 	} catch(network::error& e) {
 		std::cerr << "caught network error while server was running. aborting.: " << e.message << "\n";
 		return -1;
