@@ -1,3 +1,16 @@
+/* $Id: theme.hpp 7697 2005-08-03 21:56:48Z j_daniel $ */
+/*
+   Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
+   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY.
+
+   See the COPYING file for more details.
+*/
+
 #ifndef THEME_HPP_INCLUDED
 #define THEME_HPP_INCLUDED
 
@@ -19,6 +32,7 @@ class theme
 		object(const config& cfg);
 
 		SDL_Rect& location(const SDL_Rect& screen) const;
+		const SDL_Rect& get_location(void) const;
 
 		//all on-screen objects have 'anchoring' in the x and y dimensions
 		//'fixed' means that they have fixed co-ordinates and don't move
@@ -138,7 +152,7 @@ public:
 private:
 	static std::map<std::string, config> known_themes;
         std::string cur_theme;
-        const config& cfg_;
+        config cfg_;
 	std::vector<panel> panels_;
 	std::vector<label> labels_;
 	std::vector<menu> menus_;
