@@ -1,4 +1,4 @@
-/* $Id: unit.cpp 7953 2005-08-21 17:46:03Z gruikya $ */
+/* $Id: unit.cpp 8821 2005-11-12 19:23:56Z brunowolff $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -825,12 +825,12 @@ void unit::write(config& cfg) const
 	}
 
 	char buf[50];
-	sprintf(buf,"%d",goto_.x+1);
+	snprintf(buf,sizeof(buf),"%d",goto_.x+1);
 	cfg["goto_x"] = buf;
-	sprintf(buf,"%d",goto_.y+1);
+	snprintf(buf,sizeof(buf),"%d",goto_.y+1);
 	cfg["goto_y"] = buf;
 
-	sprintf(buf,"%d",moves_);
+	snprintf(buf,sizeof(buf),"%d",moves_);
 	cfg["moves"] = buf;
 
 	cfg["resting"] = resting_ ? "yes" : "no";
