@@ -1,3 +1,16 @@
+/* $Id: menu.hpp 7948 2005-08-21 15:24:37Z gruikya $ */
+/*
+   Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
+   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY.
+
+   See the COPYING file for more details.
+*/
+
 #ifndef WIDGET_MENU_HPP_INCLUDED
 #define WIDGET_MENU_HPP_INCLUDED
 
@@ -110,6 +123,8 @@ protected:
 	void handle_event(const SDL_Event& event);
 	void set_inner_location(const SDL_Rect& rect);
 
+	bool requires_event_focus() const { return true; };
+
 private:
 	size_t max_items_onscreen() const;
 
