@@ -1,6 +1,6 @@
-/* $Id: scrollbar.hpp,v 1.17 2005/03/18 21:21:48 ydirson Exp $ */
+/* $Id: scrollbar.hpp 7944 2005-08-21 13:11:28Z gruikya $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
                  2004 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
@@ -63,6 +63,12 @@ public:
 	/// Return true if the scrollbar has a valid size.
 	bool is_valid_height(int height) const;
 
+	/// Scrolls down one step
+	void scroll_down();
+
+	/// Scrolls up one step
+	void scroll_up();
+
 protected:
 	virtual void update_location(SDL_Rect const &rect);
 	virtual void handle_event(const SDL_Event& event);
@@ -83,7 +89,6 @@ private:
 	// Relative data
 	int grip_position_, old_position_, grip_height_, full_height_, scroll_rate_;
 
-	friend class scrollarea;
 };
 
 }
